@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2013 Magic3 Project.
+ * @copyright  Copyright 2006-2014 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -712,6 +712,44 @@ class blog_mainDb extends BaseDb
 		}
 		return $ret;
 	}
+	/**
+	 * 前後のエントリー項目を取得
+	 *
+	 * @param timestamp $regDate			登録日時
+	 * @param array     $prevRow			前のレコード
+	 * @param array     $nextRow			次のレコード
+	 * @return bool							取得 = true, 取得なし= false
+	 */
+	function getPrevNextEntryByDate($regDate, &$prevRow, &$nextRow)
+	{
+		if ($regDate == $this->gEnv->getInitValueOfTimestamp()){
+			return false;
+		} else {
+			$retStatus = false;
+			$params = array();
+			$queryStr  = 'SELECT * FROM blog_entry LEFT JOIN blog_id ON be_blog_id = bl_id AND bl_deleted = false ';
+			$queryStr .=   'WHERE be_deleted = false ';	// 削除されていない
+			$queryStr .=     'AND be_regist_dt < ? '; $params[] = $regDate;
+			$queryStr .=   'ORDER BY be_regist_dt DESC LIMIT 1';// 投稿順
+			$ret = $this->selectRecord($queryStr, $params, $row);
+			if ($ret){
+				$prevRow = $row;
+				$retStatus = true;
+			}
+			
+			$params = array();
+			$queryStr  = 'SELECT * FROM blog_entry LEFT JOIN blog_id ON be_blog_id = bl_id AND bl_deleted = false ';
+			$queryStr .=   'WHERE be_deleted = false ';	// 削除されていない
+			$queryStr .=     'AND ? < be_regist_dt '; $params[] = $regDate;
+			$queryStr .=   'ORDER BY be_regist_dt LIMIT 1';// 投稿順
+			$ret = $this->selectRecord($queryStr, $params, $row);
+			if ($ret){
+				$nextRow = $row;
+				$retStatus = true;
+			}
+		}
+		return $retStatus;
+	}
 	/**
 	 * エントリー項目を取得(表示用)
 	 *
@@ -1204,17 +1242,21 @@ class blog_mainDb extends BaseDb
 		return $this->isRecordExists($queryStr, array(intval($serial), $blogId));
 	}
 	/**
-	 * すべてのブログIDを取得
+	 * 利用可能なブログのブログIDを取得
 	 *
 	 * @param array   $rows			取得レコード
 	 * @return bool					取得 = true, 取得なし= false
 	 */
-	function getAllBlogId(&$rows)
+	function getAvailableBlogId(&$rows)
 	{
+		$params = array();
 		$queryStr  = 'SELECT * FROM blog_id ';
-		$queryStr .=  'WHERE bl_deleted = false ';		// 削除されていない
+		$queryStr .=   'WHERE bl_deleted = false ';		// 削除されていない
+		if (!$this->gEnv->isSystemManageUser()){		// コンテンツ編集可能ユーザの場合
+			$queryStr .=     'AND bl_owner_id = ? '; $params[] = $this->gEnv->getCurrentUserId();	// 現在のユーザ
+		}
 		$queryStr .=  'ORDER BY bl_index, bl_id';
-		$retValue = $this->selectRecords($queryStr, array(), $rows);
+		$retValue = $this->selectRecords($queryStr, $params, $rows);
 		return $retValue;
 	}
 	/**
@@ -1452,6 +1494,7 @@ class blog_mainDb extends BaseDb
 		// tm_device_typeは後で追加したため、tm_mobileを残しておく
 		$queryStr = 'SELECT * FROM _templates ';
 		$queryStr .=  'WHERE tm_deleted = false ';// 削除されていない
+		$queryStr .=     'AND tm_available = true ';
 		$params = array();
 		switch ($type){
 			case 0:		// PC用テンプレート
