@@ -148,10 +148,10 @@ jQuery.NiceJForms = {
 		jQuery.NiceJForms.labels[index] = $('label', el);
 		jQuery.NiceJForms.textareas[index] = $('textarea', el);
 		jQuery.NiceJForms.selects[index] = $('select', el);
-		jQuery.NiceJForms.radios[index] = $('input[@type=radio]', el);
-		jQuery.NiceJForms.checkboxes[index] = $('input[@type=checkbox]', el);
-		jQuery.NiceJForms.texts[index] = $('input[@type=text]', el).add($('input[@type=password]', el));		
-		jQuery.NiceJForms.buttons[index] = $('input[@type=submit]', el).add($('input[@type=button]', el));
+		jQuery.NiceJForms.radios[index] = $('input[type=radio]', el);
+		jQuery.NiceJForms.checkboxes[index] = $('input[type=checkbox]', el);
+		jQuery.NiceJForms.texts[index] = $('input[type=text]', el).add($('input[type=password]', el));		
+		jQuery.NiceJForms.buttons[index] = $('input[type=submit]', el).add($('input[type=button]', el));
 		jQuery.NiceJForms.checkboxLabels[index] = new Array();
 		jQuery.NiceJForms.radioLabels[index] = new Array();
 		
